==> haskell-edisonapi-1.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-26D4i6DiKfNNG9Npbqu2a
key: EdisonAPI-1.3.1-26D4i6DiKfNNG9Npbqu2a
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
author: Chris Okasaki
exposed: True
indefinite: False
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym
abi: 7f6f17d941657bffe371e0138a9965c0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/EdisonAPI-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-26D4i6DiKfNNG9Npbqu2a
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=5531911f09693672654e6de645ce55e7
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisonapi-1.3.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi
key: EdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
author: Chris Okasaki
exposed: True
indefinite: False
exposed-modules:
    Data.Edison Data.Edison.Assoc Data.Edison.Coll
    Data.Edison.Coll.Utils Data.Edison.Prelude Data.Edison.Seq
    Data.Edison.Seq.ListSeq Data.Edison.Sym
abi: 64f70a87dbc9629d563924967b81a73a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonAPI-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
